@@ -1,7 +1,7 @@
-from ._base import _Base
+from .base import Base
 
 from .enums import MTRSLabelEnum, DiagnosticsXMLTagEnum, MTRSXMLTagEnum, DoctorChoiceXMLTagEnum
-
 from .chat_item import ChatItem, OuterContextItem, InnerContextItem, ReplicaItem
+from .chat import Chat, Context, ChatMessage, AIMessage, HumanMessage, MiscMessage
 from .base_config_models import GigaChatConfig
 from .tracks import TrackInfo, DomainInfo
